@@ -716,9 +716,16 @@ def runtestswithappsurify(*args):
 
 
     #Templates
-    argv = args[0]
-    if type(argv) == tuple:
-        argv = argv[0]
+    argv=args
+    print(argv)
+    print(type(argv))
+    try:
+        argv = args[0]
+        if type(argv) == tuple:
+            argv = argv[0]
+    except: # catch *all* exceptions
+        e = sys.exc_info()[0]
+        print( "Error: %s" % e )
     c=0
     print("===================================")
     if len(argv) > 1 :
@@ -1321,8 +1328,8 @@ def runtestswithappsurify(*args):
     try:
         os.environ["TESTSTORUN"] = testsrun
     except: # catch *all* exceptions
-      e = sys.exc_info()[0]
-      print( "Error: %s" % e )
+        e = sys.exc_info()[0]
+        print( "Error: %s" % e )
     
 
     if testsrun == "":
@@ -1336,11 +1343,14 @@ def runtestswithappsurify(*args):
 
     if failfast == "false" and rerun == "true" and teststorun != "none":
         rerun_tests()
-
+        
     getresults()
 
+    exit()
+
+
 def main(*argv):
     #print(argv)
     runtestswithappsurify(argv)
-  
+    
 main(sys.argv)
\ No newline at end of file
